pub struct ApnsRouter {
clients: HashMap<String, ApnsClientData>,
settings: ApnsSettings,
endpoint_url: Url,
metrics: Arc<StatsdClient>,
db: Box<dyn DbClient>,
reliability: Arc<PushReliability>,
}Expand description
Apple Push Notification Service router
Fields
clients: HashMap<String, ApnsClientData>A map from release channel to APNS client
settings: ApnsSettingsendpoint_url: Urlmetrics: Arc<StatsdClient>db: Box<dyn DbClient>reliability: Arc<PushReliability>Implementations
Sourceimpl ApnsRouter
impl ApnsRouter
Sourcepub async fn new(
settings: ApnsSettings,
endpoint_url: Url,
metrics: Arc<StatsdClient>,
db: Box<dyn DbClient>,
reliability: Arc<PushReliability>,
) -> Result<Self, ApnsError>
pub async fn new( settings: ApnsSettings, endpoint_url: Url, metrics: Arc<StatsdClient>, db: Box<dyn DbClient>, reliability: Arc<PushReliability>, ) -> Result<Self, ApnsError>
Create a new APNS router. APNS clients will be initialized for each channel listed in the settings.
Sourceasync fn create_client(
name: String,
channel: ApnsChannel,
request_timeout_secs: Option<u64>,
pool_idle_timeout_secs: Option<u64>,
) -> Result<(String, ApnsClientData), ApnsError>
async fn create_client( name: String, channel: ApnsChannel, request_timeout_secs: Option<u64>, pool_idle_timeout_secs: Option<u64>, ) -> Result<(String, ApnsClientData), ApnsError>
Create an APNS client for the channel.
If key_id and team_id are set, the client uses token-based
authentication with the .p8 provider auth key in key. Otherwise it
falls back to certificate-based authentication with cert/key.
Sourceasync fn read_pem(value: &str) -> Result<Vec<u8>, ApnsError>
async fn read_pem(value: &str) -> Result<Vec<u8>, ApnsError>
Read PEM material that is either an inline value (starting with “-”,
e.g. -----BEGIN PRIVATE KEY-----) or a path to a file
Sourcefn default_aps<'a>() -> DefaultNotificationBuilder<'a>
fn default_aps<'a>() -> DefaultNotificationBuilder<'a>
The default APS data for a notification
Sourceasync fn handle_error(
&self,
error: Error,
uaid: Uuid,
channel: &str,
) -> ApiError
async fn handle_error( &self, error: Error, uaid: Uuid, channel: &str, ) -> ApiError
Handle an error by logging, updating metrics, etc
Sourcefn derive_aps<'a>(
&self,
replacement: Value,
holder: &'a mut ApsAlertHolder,
) -> Result<DefaultNotificationBuilder<'a>, ApnsError>
fn derive_aps<'a>( &self, replacement: Value, holder: &'a mut ApsAlertHolder, ) -> Result<DefaultNotificationBuilder<'a>, ApnsError>
Derive an APS message from the replacement JSON block.
This requires an external “holder” that contains the data that APS will refer to.
The holder should live in the same context as the aps.build() method.