pub struct Notification {
pub message_id: String,
pub subscription: Subscription,
pub headers: NotificationHeaders,
pub timestamp: u64,
pub sort_key_timestamp: u64,
pub data: Option<String>,
pub reliable_state: Option<ReliabilityState>,
pub reliability_id: Option<String>,
pub(crate) in_process_counter: Arc<AtomicUsize>,
}Expand description
Extracts notification data from Subscription and request data
Fields
message_id: StringUnique message_id for this notification
subscription: SubscriptionThe subscription information block
headers: NotificationHeadersSet of associated crypto headers
timestamp: u64UNIX timestamp in seconds
sort_key_timestamp: u64UNIX timestamp in milliseconds
data: Option<String>The encrypted notification body
reliable_state: Option<ReliabilityState>The current state the message was in (if tracked)
reliability_id: Option<String>in_process_counter: Arc<AtomicUsize>Internal reference to the appstate count of in process notifications. Note: This only tracks notifications that have been delivered from a subscription provider. This does not track notifications that may have been retrieved from storage. This counter is in response to an incident where a large number of valid, inbound notifications caused a cascade impact on our storage engine, which resulted in a node OOM error killing the process. This metric will be reported as part of the health check to allow the load balancer to make informed routing decisions.
Implementations
Sourceimpl Notification
impl Notification
Sourcefn generate_message_id(
fernet: &MultiFernet,
uaid: Uuid,
channel_id: Uuid,
topic: Option<&str>,
timestamp: u64,
) -> String
fn generate_message_id( fernet: &MultiFernet, uaid: Uuid, channel_id: Uuid, topic: Option<&str>, timestamp: u64, ) -> String
Generate a message-id suitable for accessing the message
For topic messages, a sort_key version of 01 is used, and the topic is included for reference:
Encrypted('01' : uaid.hex : channel_id.hex : topic)For non-topic messages, a sort_key version of 02 is used:
Encrypted('02' : uaid.hex : channel_id.hex : timestamp)pub fn has_topic(&self) -> bool
Sourcepub fn serialize_for_delivery(
&self,
) -> Result<TransportNotification<'_>, ApiError>
pub fn serialize_for_delivery( &self, ) -> Result<TransportNotification<'_>, ApiError>
Serialize the notification for delivery to the connection server. Some
fields in autopush_common’s Notification are marked with
#[serde(skip_serializing)] so they are not shown to the UA. These
fields are still required when delivering to the connection server, so
we can’t simply convert this notification type to that one and serialize
via serde.
pub async fn record_reliability( &mut self, reliability: &PushReliability, state: ReliabilityState, )